==> gtktalog-0.11.2.tar.gz: gtktalog-0.11.2/src/gtktalog/search.h <==
/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __SEARCH_H__
#define __SEARCH_H__

#include <config.h>
#include <gnome.h>
#include <time.h>
/*#include "data.h"*/
#include "config_common.h"

typedef struct
{
  unsigned char val;
  FOLDER *folder;
  char *data[7];		//cotient toutes les infos de Folder en char
}
search_info;

GNode *find_node_with_parent(GNode *parent, gchar *name, gboolean case_sensitive, FOLDER * racine);
gboolean find_files(GNode *gn, gpointer data);
void start_search (FOLDER * racine,  GNodeTraverseFunc cb_find_files );
void start_extended_search(GtkWidget *w, gpointer data);
void start_simple_search(GtkWidget *w, gpointer data);
void use_calendar1(GtkWidget *w, gpointer data);
void use_calendar2(GtkWidget *w, gpointer data);
void create_search_dialog(FOLDER *racine);

#endif

==> gtktalog-0.13.2.tar.gz: gtktalog-0.13.2/src/gtktalog/search.h <==
/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __SEARCH_H__
#define __SEARCH_H__

#include <config.h>
#include <gnome.h>
#include <time.h>
/*#include "data.h"*/
#include "config_common.h"

typedef struct
{
  unsigned char val;
  FOLDER *folder;
  char *data[7];		//contient toutes les infos de Folder en char
}
search_info;

GNode *find_node_with_parent(GNode *parent, gchar *name, gboolean case_sensitive, FOLDER * racine);
gboolean find_files(GNode *gn, gpointer data);
void start_search (FOLDER * racine, gboolean is_search_extended);
void start_extended_search(GtkWidget *w, gpointer data);
void start_simple_search(GtkWidget *w, gpointer data);
void use_calendar1(GtkWidget *w, gpointer data);
void use_calendar2(GtkWidget *w, gpointer data);
void create_search_dialog(FOLDER *racine);

#endif
